==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/kleopatra/conf/appearanceconfigpage.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    conf/appearanceconfigpage.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2004,2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H
#define KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H

#include <kcmodule.h>

namespace Kleo {
namespace Config {

    class AppearanceConfigWidget;

    /**
     * "Appearance" configuration page for kleopatra's configuration dialog
     */
    class AppearanceConfigurationPage : public KCModule {
        Q_OBJECT
    public:
        explicit AppearanceConfigurationPage( const KComponentData &instance, QWidget *parent=0, const QVariantList &args=QVariantList() );

        /* reimp */ void load();
        /* reimp */ void save();
        /* reimp */ void defaults();

    private:
        AppearanceConfigWidget* mWidget;
    };

}
}

#endif // KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H

==> kdepim_15.12.3.orig.tar.xz: kdepim-15.12.3/kleopatra/conf/appearanceconfigpage.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    conf/appearanceconfigpage.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2004,2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H
#define KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H

#include <kcmodule.h>
namespace Kleo
{
namespace Config
{

class AppearanceConfigWidget;

/**
 * "Appearance" configuration page for kleopatra's configuration dialog
 */
class AppearanceConfigurationPage : public KCModule
{
    Q_OBJECT
public:
    explicit AppearanceConfigurationPage(QWidget *parent = Q_NULLPTR, const QVariantList &args = QVariantList());

    void load() Q_DECL_OVERRIDE;
    void save() Q_DECL_OVERRIDE;
    void defaults() Q_DECL_OVERRIDE;

private:
    AppearanceConfigWidget *mWidget;
};

}
}

#endif // KLEOPATRA_CONFIG_APPEARANCECONFIGPAGE_H
